@@ -24,7 +24,7 @@ package org.apache.commons.pool;
  *
  * @author Rodney Waldhoff
  * @author Sandy McArthur
- * @version $Revision: 791364 $ $Date: 2009-07-05 21:52:27 -0400 (Sun, 05 Jul 2009) $
+ * @version $Revision: 1084645 $ $Date: 2011-03-23 10:11:19 -0700 (Wed, 23 Mar 2011) $
  * @since Pool 1.0
  */
 public abstract class BaseObjectPool implements ObjectPool {
@@ -44,15 +44,13 @@ public abstract class BaseObjectPool implements ObjectPool {
     public abstract void returnObject(Object obj) throws Exception;
     
     /**
-     * Invalidates an object from the pool.
-     * By contract, <code>obj</code> <strong>must</strong> have been obtained
-     * using {@link #borrowObject borrowObject}
-     * or a related method as defined in an implementation
-     * or sub-interface.
-     * <p>
-     * This method should be used when an object that has been borrowed
-     * is determined (due to an exception or other problem) to be invalid.
-     * </p>
+     * <p>Invalidates an object from the pool.</p>
+     * 
+     * <p>By contract, <code>obj</code> <strong>must</strong> have been obtained
+     * using {@link #borrowObject borrowObject}.<p>
+     * 
+     * <p>This method should be used when an object that has been borrowed
+     * is determined (due to an exception or other problem) to be invalid.</p>
      *
      * @param obj a {@link #borrowObject borrowed} instance to be disposed.
      * @throws Exception 
@@ -115,6 +113,7 @@ public abstract class BaseObjectPool implements ObjectPool {
      * @param factory the PoolableObjectFactory
      * @throws UnsupportedOperationException
      * @throws IllegalStateException
+     * @deprecated to be removed in pool 2.0
      */
     public void setFactory(PoolableObjectFactory factory) throws IllegalStateException, UnsupportedOperationException {
         throw new UnsupportedOperationException();
@@ -124,7 +123,7 @@ public abstract class BaseObjectPool implements ObjectPool {
      * Has this pool instance been closed.
      * @return <code>true</code> when this pool has been closed.
      */
-    protected final boolean isClosed() {
+    public final boolean isClosed() {
         return closed;
     }
 
