@@ -16,13 +16,11 @@
  */
 package org.apache.commons.pool;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
 
 /**
  * @author Rodney Waldhoff
  * @author Sandy McArthur
- * @version $Revision: 606064 $ $Date: 2007-12-20 19:12:02 -0500 (Thu, 20 Dec 2007) $
+ * @version $Revision: 901944 $ $Date: 2010-01-21 17:27:04 -0700 (Thu, 21 Jan 2010) $
  */
 public class TestBaseKeyedObjectPool extends TestKeyedObjectPool {
     private KeyedObjectPool _pool = null;
@@ -71,11 +69,6 @@ public class TestBaseKeyedObjectPool extends TestKeyedObjectPool {
         throw new UnsupportedOperationException("BaseKeyedObjectPool isn't a complete implementation.");
     }
 
-    public static Test suite() {
-        return new TestSuite(TestBaseKeyedObjectPool.class);
-    }
-
-    // tests
     public void setUp() throws Exception {
         super.setUp();
     }
