@@ -16,13 +16,11 @@
  */
 package org.apache.commons.pool;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
 
 /**
  * @author Rodney Waldhoff
  * @author Sandy McArthur
- * @version $Revision: 606064 $ $Date: 2007-12-20 17:12:02 -0700 (Thu, 20 Dec 2007) $ 
+ * @version $Revision: 901944 $ $Date: 2010-01-21 17:27:04 -0700 (Thu, 21 Jan 2010) $ 
  */
 public class TestBaseObjectPool extends TestObjectPool {
     private ObjectPool _pool = null;
@@ -31,10 +29,6 @@ public class TestBaseObjectPool extends TestObjectPool {
         super(testName);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestBaseObjectPool.class);
-    }
-    
     protected ObjectPool makeEmptyPool(int mincapacity) {
         if (this.getClass() != TestBaseObjectPool.class) {
             fail("Subclasses of TestBaseObjectPool must reimplement this method.");
