@@ -16,24 +16,17 @@
  */
 package org.apache.commons.pool;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
 /**
  * @author Rodney Waldhoff
- * @version $Revision: 480413 $ $Date: 2006-11-29 00:16:05 -0500 (Wed, 29 Nov 2006) $ 
+ * @version $Revision: 901944 $ $Date: 2010-01-21 17:27:04 -0700 (Thu, 21 Jan 2010) $ 
  */
 public class TestBasePoolableObjectFactory extends TestCase {
     public TestBasePoolableObjectFactory(String testName) {
         super(testName);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestBasePoolableObjectFactory.class);
-    }
-    
-    // tests
     public void testDefaultMethods() throws Exception {
         PoolableObjectFactory factory = new BasePoolableObjectFactory() { 
             public Object makeObject() throws Exception {
