@@ -30,7 +30,7 @@ import java.util.NoSuchElementException;
  * Abstract {@link TestCase} for {@link ObjectPool} implementations.
  * @author Rodney Waldhoff
  * @author Sandy McArthur
- * @version $Revision: 607137 $ $Date: 2007-12-27 16:06:49 -0700 (Thu, 27 Dec 2007) $
+ * @version $Revision: 775703 $ $Date: 2009-05-17 09:39:51 -0700 (Sun, 17 May 2009) $
  */
 public abstract class TestObjectPool extends TestCase {
     public TestObjectPool(String testName) {
@@ -254,7 +254,6 @@ public abstract class TestObjectPool extends TestCase {
         }
         final List expectedMethods = new ArrayList();
         Object obj;
-        int idleCount;
 
         /// Test correct behavior code paths
         obj = pool.borrowObject();
@@ -279,7 +278,7 @@ public abstract class TestObjectPool extends TestCase {
         assertEquals(3, pool.getNumIdle());
         // passivateObject should swallow exceptions and not add the object to the pool
         obj = pool.borrowObject();
-        Object obj2 = pool.borrowObject();
+        pool.borrowObject();
         assertEquals(1, pool.getNumIdle());
         assertEquals(2, pool.getNumActive());
         clear(factory, expectedMethods);
