@@ -17,34 +17,28 @@
 
 package org.apache.commons.pool.impl;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import java.util.NoSuchElementException;
+import java.util.Random;
+
 import org.apache.commons.pool.BasePoolableObjectFactory;
 import org.apache.commons.pool.ObjectPool;
-import org.apache.commons.pool.PoolableObjectFactory;
 import org.apache.commons.pool.PoolUtils;
+import org.apache.commons.pool.PoolableObjectFactory;
 import org.apache.commons.pool.TestBaseObjectPool;
 import org.apache.commons.pool.VisitTracker;
 import org.apache.commons.pool.VisitTrackerFactory;
 
-import java.util.NoSuchElementException;
-import java.util.Random;
-
 /**
  * @author Rodney Waldhoff
  * @author Dirk Verbeeck
  * @author Sandy McArthur
- * @version $Revision: 831698 $ $Date: 2009-11-01 11:33:31 -0500 (Sun, 01 Nov 2009) $
+ * @version $Revision: 1084991 $ $Date: 2011-03-24 08:17:20 -0700 (Thu, 24 Mar 2011) $
  */
 public class TestGenericObjectPool extends TestBaseObjectPool {
     public TestGenericObjectPool(String testName) {
         super(testName);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestGenericObjectPool.class);
-    }
-
     protected ObjectPool makeEmptyPool(int mincap) {
        GenericObjectPool pool = new GenericObjectPool(new SimpleFactory());
        pool.setMaxActive(mincap);
@@ -116,6 +110,46 @@ public class TestGenericObjectPool extends TestBaseObjectPool {
         pool.close();
     }
 
+    public void testWhenExhaustedBlockInterupt() throws Exception {
+        pool.setMaxActive(1);
+        pool.setWhenExhaustedAction(GenericObjectPool.WHEN_EXHAUSTED_BLOCK);
+        pool.setMaxWait(0);
+        Object obj1 = pool.borrowObject();
+        
+        // Make sure on object was obtained
+        assertNotNull(obj1);
+        
+        // Create a separate thread to try and borrow another object
+        WaitingTestThread wtt = new WaitingTestThread(pool, 200);
+        wtt.start();
+        // Give wtt time to start
+        Thread.sleep(200);
+        wtt.interrupt();
+
+        // Give interupt time to take effect
+        Thread.sleep(200);
+        
+        // Check thread was interrupted
+        assertTrue(wtt._thrown instanceof InterruptedException);
+
+        // Return object to the pool
+        pool.returnObject(obj1);
+        
+        // Bug POOL-162 - check there is now an object in the pool
+        pool.setMaxWait(10L);
+        Object obj2 = null;
+        try {
+             obj2 = pool.borrowObject();
+            assertNotNull(obj2);
+        } catch(NoSuchElementException e) {
+            // Not expected
+            fail("NoSuchElementException not expected");
+        }
+        pool.returnObject(obj2);
+        pool.close();
+        
+    }
+
     public void testEvictWhileEmpty() throws Exception {
         pool.evict();
         pool.evict();
@@ -1130,6 +1164,51 @@ public class TestGenericObjectPool extends TestBaseObjectPool {
         runTestThreads(5, 10, 50);
     }
 
+    public void testConcurrentBorrowAndEvict() throws Exception {
+
+        pool.setMaxActive(1);
+        pool.addObject();
+
+        for( int i=0; i<5000; i++) {
+            ConcurrentBorrowAndEvictThread one =
+                    new ConcurrentBorrowAndEvictThread(true);
+            ConcurrentBorrowAndEvictThread two =
+                    new ConcurrentBorrowAndEvictThread(false);
+
+            one.start();
+            two.start();
+            one.join();
+            two.join();
+
+            pool.returnObject(one.obj);
+            
+            /* Uncomment this for a progress indication
+            if (i % 10 == 0) {
+                System.out.println(i/10);
+            }
+            */
+        }
+    }
+
+    private class ConcurrentBorrowAndEvictThread extends Thread {
+        private boolean borrow;
+        public Object obj;
+        
+        public ConcurrentBorrowAndEvictThread(boolean borrow) {
+            this.borrow = borrow;
+        }
+
+        public void run() {
+            try {
+                if (borrow) {
+                    obj = pool.borrowObject();
+                } else {
+                    pool.evict();
+                }
+            } catch (Exception e) { /* Ignore */}
+        }
+    }
+
     static class TestThread implements Runnable {
         private final java.util.Random _random = new java.util.Random();
         
@@ -1298,69 +1377,113 @@ public class TestGenericObjectPool extends TestBaseObjectPool {
             evenValid = evalid;
             oddValid = ovalid;
         }
-        void setValid(boolean valid) {
+        public synchronized void setValid(boolean valid) {
             setEvenValid(valid);
             setOddValid(valid);            
         }
-        void setEvenValid(boolean valid) {
+        public synchronized void setEvenValid(boolean valid) {
             evenValid = valid;
         }
-        void setOddValid(boolean valid) {
+        public synchronized void setOddValid(boolean valid) {
             oddValid = valid;
         }
-        public void setThrowExceptionOnPassivate(boolean bool) {
+        public synchronized void setThrowExceptionOnPassivate(boolean bool) {
             exceptionOnPassivate = bool;
         }
-        public void setMaxActive(int maxActive) {
+        public synchronized void setMaxActive(int maxActive) {
             this.maxActive = maxActive;
         }
-        public void setDestroyLatency(long destroyLatency) {
+        public synchronized void setDestroyLatency(long destroyLatency) {
             this.destroyLatency = destroyLatency;
         }
-        public void setMakeLatency(long makeLatency) {
+        public synchronized void setMakeLatency(long makeLatency) {
             this.makeLatency = makeLatency;
         }
+        public synchronized void setValidateLatency(long validateLatency) {
+            this.validateLatency = validateLatency;
+        }
         public Object makeObject() { 
+            final long waitLatency;
             synchronized(this) {
                 activeCount++;
                 if (activeCount > maxActive) {
                     throw new IllegalStateException(
                         "Too many active instances: " + activeCount);
                 }
+                waitLatency = makeLatency;
             }
-            if (makeLatency > 0) {
-                doWait(makeLatency);
+            if (waitLatency > 0) {
+                doWait(waitLatency);
             }
-            return String.valueOf(makeCounter++);
+            final int counter;
+            synchronized(this) {
+                counter = makeCounter++;
+            }
+            return String.valueOf(counter);
         }
         public void destroyObject(Object obj) throws Exception {
-            if (destroyLatency > 0) {
-                doWait(destroyLatency);
+            final long waitLatency;
+            final boolean hurl;
+            synchronized(this) {
+                waitLatency = destroyLatency;
+                hurl = exceptionOnDestroy;
+            }
+            if (waitLatency > 0) {
+                doWait(waitLatency);
             }
             synchronized(this) {
                 activeCount--;
             }
-            if (exceptionOnDestroy) {
+            if (hurl) {
                 throw new Exception();
             }
         }
         public boolean validateObject(Object obj) {
-            if (enableValidation) { 
-                return validateCounter++%2 == 0 ? evenValid : oddValid; 
+            final boolean validate;
+            final boolean evenTest;
+            final boolean oddTest;
+            final long waitLatency;
+            final int counter;
+            synchronized(this) {
+                validate = enableValidation;
+                evenTest = evenValid;
+                oddTest = oddValid;
+                counter = validateCounter++;
+                waitLatency = validateLatency;
+            }
+            if (waitLatency > 0) {
+                doWait(waitLatency);
+            }
+            if (validate) { 
+                return counter%2 == 0 ? evenTest : oddTest; 
             }
             else {
                 return true;
             }
         }
         public void activateObject(Object obj) throws Exception {
-            if (exceptionOnActivate) {
-                if (!(validateCounter++%2 == 0 ? evenValid : oddValid)) {
+            final boolean hurl;
+            final boolean evenTest;
+            final boolean oddTest;
+            final int counter;
+            synchronized(this) {
+                hurl = exceptionOnActivate;
+                evenTest = evenValid;
+                oddTest = oddValid;
+                counter = validateCounter++;
+            }
+            if (hurl) {
+                if (!(counter%2 == 0 ? evenTest : oddTest)) {
                     throw new Exception();
                 }
             }
         }
         public void passivateObject(Object obj) throws Exception {
-            if(exceptionOnPassivate) {
+            final boolean hurl;
+            synchronized(this) {
+                hurl = exceptionOnPassivate;
+            }
+            if (hurl) {
                 throw new Exception();
             }
         }
@@ -1375,28 +1498,33 @@ public class TestGenericObjectPool extends TestBaseObjectPool {
         boolean enableValidation = true;
         long destroyLatency = 0;
         long makeLatency = 0;
+        long validateLatency = 0;
         int maxActive = Integer.MAX_VALUE;
 
-        public boolean isThrowExceptionOnActivate() {
+        public synchronized boolean isThrowExceptionOnActivate() {
             return exceptionOnActivate;
         }
 
-        public void setThrowExceptionOnActivate(boolean b) {
+        public synchronized void setThrowExceptionOnActivate(boolean b) {
             exceptionOnActivate = b;
         }
         
-        public void setThrowExceptionOnDestroy(boolean b) {
+        public synchronized void setThrowExceptionOnDestroy(boolean b) {
             exceptionOnDestroy = b;
         }
 
-        public boolean isValidationEnabled() {
+        public synchronized boolean isValidationEnabled() {
             return enableValidation;
         }
 
-        public void setValidationEnabled(boolean b) {
+        public synchronized void setValidationEnabled(boolean b) {
             enableValidation = b;
         }
         
+        public synchronized int getMakeCounter() {
+            return makeCounter;
+        }
+        
         private void doWait(long latency) {
             try {
                 Thread.sleep(latency);
@@ -1505,4 +1633,129 @@ public class TestGenericObjectPool extends TestBaseObjectPool {
         }
         
     }
+
+    /*
+     * Very simple test thread that just tries to borrow an object from
+     * the provided pool returns it after a wait
+     */
+    static class WaitingTestThread extends Thread {
+        private final GenericObjectPool _pool;
+        private final long _pause;
+        private Throwable _thrown;
+        
+        private long preborrow; // just before borrow
+        private long postborrow; //  borrow returned
+        private long postreturn; // after object was returned
+        private long ended;
+        private String objectId;
+
+        public WaitingTestThread(GenericObjectPool pool, long pause) {
+            _pool = pool;
+            _pause = pause;
+            _thrown = null;
+        }
+
+        public void run() {
+            try {
+                preborrow = System.currentTimeMillis();
+                Object obj = _pool.borrowObject();
+                objectId=obj.toString();
+                postborrow = System.currentTimeMillis();
+                Thread.sleep(_pause);
+                _pool.returnObject(obj);
+                postreturn = System.currentTimeMillis();
+            } catch (Exception e) {
+                _thrown = e;
+            } finally{
+                ended = System.currentTimeMillis();
+            }
+        }
+    }
+
+    private static final boolean DISPLAY_THREAD_DETAILS=
+        Boolean.valueOf(System.getProperty("TestGenericObjectPool.display.thread.details", "false")).booleanValue();
+    // To pass this to a Maven test, use:
+    // mvn test -DargLine="-DTestGenericObjectPool.display.thread.details=true"
+    // @see http://jira.codehaus.org/browse/SUREFIRE-121
+
+    /*
+     * Test multi-threaded pool access.
+     * Multiple threads, but maxActive only allows half the threads to succeed.
+     * 
+     * This test was prompted by Continuum build failures in the Commons DBCP test case:
+     * TestPerUserPoolDataSource.testMultipleThreads2()
+     * Let's see if the this fails on Continuum too!
+     */
+    public void testMaxWaitMultiThreaded() throws Exception {
+        final long maxWait = 500; // wait for connection
+        final long holdTime = 2 * maxWait; // how long to hold connection
+        final int threads = 10; // number of threads to grab the object initially
+        SimpleFactory factory = new SimpleFactory();
+        GenericObjectPool pool = new GenericObjectPool(factory);
+        pool.setWhenExhaustedAction(GenericObjectPool.WHEN_EXHAUSTED_BLOCK);
+        pool.setMaxWait(maxWait);
+        pool.setMaxActive(threads);
+        // Create enough threads so half the threads will have to wait
+        WaitingTestThread wtt[] = new WaitingTestThread[threads * 2];
+        for(int i=0; i < wtt.length; i++){
+            wtt[i] = new WaitingTestThread(pool,holdTime);
+        }
+        long origin = System.currentTimeMillis()-1000;
+        for(int i=0; i < wtt.length; i++){
+            wtt[i].start();
+        }
+        int failed = 0;
+        for(int i=0; i < wtt.length; i++){
+            wtt[i].join();
+            if (wtt[i]._thrown != null){
+                failed++;
+            }
+        }
+        if (DISPLAY_THREAD_DETAILS || wtt.length/2 != failed){
+            System.out.println(
+                    "MaxWait: "+maxWait
+                    +" HoldTime: "+holdTime
+                    + " MaxActive: "+threads
+                    +" Threads: "+wtt.length
+                    +" Failed: "+failed
+                    );
+            for(int i=0; i < wtt.length; i++){
+                WaitingTestThread wt = wtt[i];
+                System.out.println(
+                        "Preborrow: "+(wt.preborrow-origin)
+                        + " Postborrow: "+(wt.postborrow != 0 ? wt.postborrow-origin : -1)
+                        + " BorrowTime: "+(wt.postborrow != 0 ? wt.postborrow-wt.preborrow : -1)
+                        + " PostReturn: "+(wt.postreturn != 0 ? wt.postreturn-origin : -1)
+                        + " Ended: "+(wt.ended-origin)
+                        + " ObjId: "+wt.objectId
+                        );
+            }            
+        }
+        assertEquals("Expected half the threads to fail",wtt.length/2,failed);
+    }
+    
+    /**
+     * Test the following scenario:
+     *   Thread 1 borrows an instance
+     *   Thread 2 starts to borrow another instance before thread 1 returns its instance
+     *   Thread 1 returns its instance while thread 2 is validating its newly created instance
+     * The test verifies that the instance created by Thread 2 is not leaked.
+     */
+    public void testMakeConcurrentWithReturn() throws Exception {
+        SimpleFactory factory = new SimpleFactory();
+        GenericObjectPool pool = new GenericObjectPool(factory); 
+        pool.setTestOnBorrow(true);
+        factory.setValid(true);
+        // Borrow and return an instance, with a short wait
+        WaitingTestThread thread1 = new WaitingTestThread(pool, 200);
+        thread1.start();
+        Thread.sleep(50); // wait for validation to succeed
+        // Slow down validation and borrow an instance
+        factory.setValidateLatency(400);
+        Object instance = pool.borrowObject();
+        // Now make sure that we have not leaked an instance
+        assertEquals(factory.getMakeCounter(), pool.getNumIdle() + 1); 
+        pool.returnObject(instance);
+        assertEquals(factory.getMakeCounter(), pool.getNumIdle());
+    }
 }
