@@ -17,30 +17,24 @@
 
 package org.apache.commons.pool.impl;
 
-import org.apache.commons.pool.TestObjectPoolFactory;
+import java.util.NoSuchElementException;
+
+import org.apache.commons.pool.MethodCallPoolableObjectFactory;
 import org.apache.commons.pool.ObjectPoolFactory;
 import org.apache.commons.pool.PoolableObjectFactory;
-import org.apache.commons.pool.MethodCallPoolableObjectFactory;
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-import java.util.NoSuchElementException;
+import org.apache.commons.pool.TestObjectPoolFactory;
 
 /**
  * Tests for {@link GenericObjectPoolFactory}.
  *
  * @author Sandy McArthur
- * @version $Revision: 604116 $ $Date: 2007-12-14 02:03:04 -0500 (Fri, 14 Dec 2007) $
+ * @version $Revision: 901944 $ $Date: 2010-01-21 17:27:04 -0700 (Thu, 21 Jan 2010) $
  */
 public class TestGenericObjectPoolFactory extends TestObjectPoolFactory {
     public TestGenericObjectPoolFactory(final String name) {
         super(name);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestGenericObjectPoolFactory.class);
-    }
-
     protected ObjectPoolFactory makeFactory(final PoolableObjectFactory objectFactory) throws UnsupportedOperationException {
         return new GenericObjectPoolFactory(objectFactory);
     }
