@@ -17,19 +17,19 @@
 
 package org.apache.commons.pool.impl;
 
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-import org.apache.commons.pool.BasePoolableObjectFactory;
-import org.apache.commons.pool.PoolableObjectFactory;
-
 import java.util.Arrays;
 import java.util.LinkedList;
 import java.util.List;
 
+import junit.framework.TestCase;
+
+import org.apache.commons.pool.BasePoolableObjectFactory;
+import org.apache.commons.pool.PoolableObjectFactory;
+
 /**
  * @author Dirk Verbeeck
  * @author Sandy McArthur
- * @version $Revision: 480413 $ $Date: 2006-11-29 00:16:05 -0500 (Wed, 29 Nov 2006) $
+ * @version $Revision: 1084639 $ $Date: 2011-03-23 10:02:42 -0700 (Wed, 23 Mar 2011) $
  */
 public class TestSoftRefOutOfMemory extends TestCase {
     private SoftReferenceObjectPool pool;
@@ -38,10 +38,6 @@ public class TestSoftRefOutOfMemory extends TestCase {
         super(testName);
     }
 
-    public static TestSuite suite() {
-        return new TestSuite(TestSoftRefOutOfMemory.class);
-    }
-
     public void tearDown() throws Exception {
         if (pool != null) {
             pool.close();
@@ -64,7 +60,11 @@ public class TestSoftRefOutOfMemory extends TestCase {
         final Runtime runtime = Runtime.getRuntime();
         while (pool.getNumIdle() > 0) {
             try {
-                garbage.add(new byte[Math.min(1024 * 1024, (int)runtime.freeMemory()/2)]);
+                long freeMemory = runtime.freeMemory();
+                if (freeMemory > Integer.MAX_VALUE) {
+                    freeMemory = Integer.MAX_VALUE;
+                }
+                garbage.add(new byte[Math.min(1024 * 1024, (int)freeMemory/2)]);
             } catch (OutOfMemoryError oome) {
                 System.gc();
             }
@@ -99,7 +99,11 @@ public class TestSoftRefOutOfMemory extends TestCase {
         final Runtime runtime = Runtime.getRuntime();
         while (pool.getNumIdle() > 0) {
             try {
-                garbage.add(new byte[Math.min(1024 * 1024, (int)runtime.freeMemory()/2)]);
+                long freeMemory = runtime.freeMemory();
+                if (freeMemory > Integer.MAX_VALUE) {
+                    freeMemory = Integer.MAX_VALUE;
+                }
+                garbage.add(new byte[Math.min(1024 * 1024, (int)freeMemory/2)]);
             } catch (OutOfMemoryError oome) {
                 System.gc();
             }
@@ -130,7 +134,11 @@ public class TestSoftRefOutOfMemory extends TestCase {
         final Runtime runtime = Runtime.getRuntime();
         while (pool.getNumIdle() > 0) {
             try {
-                garbage.add(new byte[Math.min(1024 * 1024, (int)runtime.freeMemory()/2)]);
+                long freeMemory = runtime.freeMemory();
+                if (freeMemory > Integer.MAX_VALUE) {
+                    freeMemory = Integer.MAX_VALUE;
+                }
+                garbage.add(new byte[Math.min(1024 * 1024, (int)freeMemory/2)]);
             } catch (OutOfMemoryError oome) {
                 System.gc();
             }
@@ -176,7 +184,28 @@ public class TestSoftRefOutOfMemory extends TestCase {
             }
         });
 
-        pool.returnObject(pool.borrowObject());
+        try {
+            pool.borrowObject();
+            fail("Expected out of memory.");
+        }
+        catch (OutOfMemoryError ex) {
+            // expected
+        }
+        pool.close();
+        
+        pool = new SoftReferenceObjectPool(new BasePoolableObjectFactory() {
+            public Object makeObject() throws Exception {
+                return new Object();
+            }
+
+            public boolean validateObject(Object obj) {
+                throw new IllegalAccessError();
+            }
+
+            public void destroyObject(Object obj) throws Exception {
+                throw new OutOfMemoryError();
+            }
+        });
 
         try {
             pool.borrowObject();
@@ -186,6 +215,7 @@ public class TestSoftRefOutOfMemory extends TestCase {
             // expected
         }
         pool.close();
+
     }
 
 
