@@ -21,26 +21,19 @@ import java.util.BitSet;
 import java.util.HashMap;
 import java.util.NoSuchElementException;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
 import org.apache.commons.pool.KeyedObjectPool;
 import org.apache.commons.pool.KeyedPoolableObjectFactory;
 import org.apache.commons.pool.TestBaseKeyedObjectPool;
 
 /**
  * @author Rodney Waldhoff
- * @version $Revision: 775703 $ $Date: 2009-05-17 12:39:51 -0400 (Sun, 17 May 2009) $
+ * @version $Revision: 958393 $ $Date: 2010-06-27 09:32:43 -0700 (Sun, 27 Jun 2010) $
  */
 public class TestStackKeyedObjectPool extends TestBaseKeyedObjectPool {
     public TestStackKeyedObjectPool(String testName) {
         super(testName);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestStackKeyedObjectPool.class);
-    }
-
     protected KeyedObjectPool makeEmptyPool(int mincapacity) {
         StackKeyedObjectPool pool = new StackKeyedObjectPool(new SimpleFactory(),mincapacity);
         return pool;
@@ -117,6 +110,24 @@ public class TestStackKeyedObjectPool extends TestBaseKeyedObjectPool {
             assertEquals((i < 8 ? i+1 : 8),pool.getNumIdle(""));
         }
     }
+    
+    /**
+     * Verifies maxSleeping contract: When returnObject triggers maxSleeping exceeded,
+     * the bottom (oldest) instance in the pool is destroyed to make room for the newly
+     * returning instance, which is pushed onto the idle object stack.
+     */
+    public void testRemoveOldest() throws Exception {
+        pool._maxSleeping = 2;
+        Object obj0 = pool.borrowObject("");
+        Object obj1 = pool.borrowObject("");
+        Object obj2 = pool.borrowObject("");
+        pool.returnObject("", obj0); // Push 0 onto bottom of stack
+        pool.returnObject("", obj1); // Push 1
+        pool.returnObject("", obj2); // maxSleeping exceeded -> 0 destroyed, 2 pushed
+        assertEquals("2", pool.borrowObject("")); // 2 was pushed on top
+        assertEquals("1", pool.borrowObject("")); // 1 still there
+        assertEquals("3", pool.borrowObject("")); // New instance created (0 is gone)
+    }
 
     public void testPoolWithNullFactory() throws Exception {
         KeyedObjectPool pool = new StackKeyedObjectPool(10);
