@@ -17,27 +17,21 @@
 
 package org.apache.commons.pool.impl;
 
-import org.apache.commons.pool.TestKeyedObjectPoolFactory;
 import org.apache.commons.pool.KeyedObjectPoolFactory;
 import org.apache.commons.pool.KeyedPoolableObjectFactory;
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.apache.commons.pool.TestKeyedObjectPoolFactory;
 
 /**
  * Tests for {@link StackKeyedObjectPoolFactory}.
  *
  * @author Sandy McArthur
- * @version $Revision: 480413 $ $Date: 2006-11-29 00:16:05 -0500 (Wed, 29 Nov 2006) $
+ * @version $Revision: 901944 $ $Date: 2010-01-21 17:27:04 -0700 (Thu, 21 Jan 2010) $
  */
 public class TestStackKeyedObjectPoolFactory extends TestKeyedObjectPoolFactory {
     public TestStackKeyedObjectPoolFactory(final String name) {
         super(name);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestStackKeyedObjectPoolFactory.class);
-    }
-
     protected KeyedObjectPoolFactory makeFactory(final KeyedPoolableObjectFactory objectFactory) throws UnsupportedOperationException {
         return new StackKeyedObjectPoolFactory(objectFactory);
     }
